@@ -1,9 +1,10 @@
 package NG::Class;
 use strict;
 use warnings;
+use Data::Dumper;
 
 =head2 def
-    def_class Animal => undef => ['sex', 'leg_color'] => {
+    def_class Animal => ['sex', 'leg_color'] => {
         sound => sub {  .... },
         run => sub { .... },
     };
@@ -17,10 +18,14 @@ use warnings;
     $x->eat('bone');
 =cut
 sub def {
-    my ($class, $parent, $attrs, $methods) = @_;
+    my $class   = shift;
+    my $methods = pop;
+    my $attrs   = pop;
+    my $parent  = shift || 'NG::Object';
+    
 
     eval "package $class";
-    eval "use $class";
+    eval "use $parent";
     if( $parent ne 'undef' ) {
         *t = eval('*'.$class.'::ISA');
         *t = [$parent];
@@ -40,19 +45,26 @@ sub def {
         };
     }
 
+    *t = eval('*'.$class.'::meta');
+    *t = sub {
+        my (@attr_list, @method_list, %seen);
+        if( $parent ne 'undef' ) {
+            push @attr_list,   @{ $parent->meta->{attrs} } if $parent->meta->{attrs};
+            push @method_list, @{ $parent->meta->{methods} } if $parent->meta->{methods};
+        }
+        push @attr_list, @{$attrs};
+        push @method_list, keys %{$methods};
+        return { attrs   => [ grep { not $seen{$_}++ } @attr_list ],
+                 methods => [ grep { not $seen{$_}++ } @method_list ],
+        };
+    };
+
     *t = eval('*'.$class.'::new');
     *t = sub {
-        my $o = bless {map {($_, undef)} @$attrs}, $class;
-        my $args;
         my ($class, @args) = @_;
-        if(scalar(@args)==1){
-            $args = $args[0];
-        }
-        else{
-            $args = \@args;
-        }
+        my $o = bless {@args}, ref $class || $class;
         if(defined $methods->{build}){
-            $o->build($args);
+            $o->build(@args);
         }
         $o;
     }
